#!/bin/sh
### BEGIN INIT INFO
#
# Provides: CineDigitalManagerMusic
# Required-Start:    $remote_fs $syslog CineDigitalManagerDB
# Required-Stop:     $remote_fs $syslog
# Should-Start:      $network $time
# Should-Stop:       $network $time
# Default-Start: 2 3 4 5
# Default-Stop: 0 1 6
# Short-Description: CineDigitalManager PreShowMusicService
# Description: CineDigitalManager PreShowMusicService
#
### END INIT INFO


WEBSERVICE=$(grep "PreShowMusicService=1" /usr/share/CineDigitalManager/config.properties | wc -l)
PSMBI=$(grep '^PreShowMusicBroadcastInterface' /usr/share/CineDigitalManager/config.properties|cut -d= -f 2|tr -d '[:cntrl:]' )
PSMBA=$(grep '^PreShowMusicBroadcastAddress' /usr/share/CineDigitalManager/config.properties|cut -d= -f 2|tr -d '[:cntrl:]' )

if [ $WEBSERVICE -ne 1 ]; then
	echo "Service is not enabled (/usr/share/CineDigitalManager/config.properties file must contain PreShowMusicService=1)"
	exit 0
fi

if [ "xxx$PSMBA" = "xxx" ]; then
    PSMBA=224.1.2.3
fi
unset DISPLAY
export Description="CineDigitalManager PreShowMusicService"
export javapath=`which java`
export pidfile="/var/run/CineDigitalManagerPreShowMusicService.pid"
export cdmwsdcommand="$javapath -- -Xmx1024m -cp /usr/share/CineDigitalManager/CineDigitalManager-2.4.39.jar fr.cinedigitalservicetms.tms.musiqueAmbianceService.MusiqueAmbianceParDefaut /usr/share/CineDigitalManager"

start() {
	if [ -e $pidfile ] ; then
		PID=$(myjavapid) || true
		if [ -n "$PID" ]; then
			echo "${Description} is already running (pid $PID)"
			return 0
		else
			echo "\nOops: Looks like ${Description} crashed! \n\n"
			rm -f $pidfile
		fi
	fi

    if [ "xxx$PSMBI" != "xxx" ]; then
        STOP=0
        while [ $STOP -lt 10 ]; do
            if [ -f /sys/class/net/$PSMBI/operstate ]; then
                STATE=$(cat /sys/class/net/$PSMBI/operstate)
            else
                STATE=down
            fi
            if [ "xxx$STATE" = "xxxup" ]; then
                route add -host $PSMBA dev $PSMBI
                STOP=99
            else 
                sleep 1
                STOP=$(expr $STOP + 1)
            fi
        done
    fi
	start-stop-daemon --start --background --make-pidfile --pidfile $pidfile --exec $cdmwsdcommand

	# we make sure that java had enough time to start as it is starting in the background    
	sleep 1

	PID=$(myjavapid) || true
    echo "${Description} is now running (pid $PID)"

    if [ "xxx$PID" != "xxx" ]; then
        renice -5 -p $PID
    fi
}

stop() {
	start-stop-daemon --stop --quiet --pidfile $pidfile

    route del -host $PSMBA

	if [ -e $pidfile ] ; then
		rm -f $pidfile
	fi
	echo "${Description} is now stopped"
}

myjavapid() {
	if [ -e "$pidfile" ]; then
		if pidof java | tr ' ' '\n' | grep -w $(cat $pidfile); then
			return 0
		fi
	fi
	return 1
}

case "$1" in
  start)
	start
	;;
  stop)
	stop
	;;
  restart|reload|force-reload)
  	stop
	sleep 2
  	start
	;;
  status)
	PID=$(myjavapid) || true
	if [ -n "$PID" ]; then
		echo "${Description} is running (pid $PID)"
	else
		echo "${Description} is not running"
	fi
	;;
  *)
	echo $"Usage: $0 {start|stop|restart|status}"
	exit 1
esac

exit 0


