#!/bin/sh
### BEGIN INIT INFO
#
# Provides: CineDigitalManagerDB
# Required-Start:    $remote_fs $syslog
# Required-Stop:     $remote_fs $syslog
# Should-Start:      $network $time
# Should-Stop:       $network $time
# Default-Start: 2 3 4 5
# Default-Stop: 0 1 6
# Short-Description: CineDigitalManager Database
# Description: CineDigitalManager Database
#
### END INIT INFO

export Description="CineDigitalManager Database"
export javapath=`which java`
export pidfile="/var/run/CineDigitalManagerDB.pid"
export cdmwsdcommand="$javapath -- -Xmx1024m -cp /usr/share/CineDigitalManager/lib/hsqldb-db.jar org.hsqldb.Server -database.0 file://usr/share/CineDigitalManager/BDD/cdsdb -dbname.0 cdsdb"

start() {
	if [ -e $pidfile ] ; then
		PID=$(myjavapid) || true
		if [ -n "$PID" ]; then
			echo "${Description} is already running (pid $PID)"
			return 0
		else
			echo "\nOops: Looks like ${Description} crashed! \n\n"
			rm -f $pidfile
		fi
	fi
	if [ ! -s /usr/share/CineDigitalManager/BDD/cdsdb.backup ]; then
        	rm -f /usr/share/CineDigitalManager/BDD/cdsdb.backup
	fi

	rm -f /usr/share/CineDigitalManager/BDD/cdsdb.lck

	start-stop-daemon --start --background --make-pidfile --pidfile $pidfile --exec $cdmwsdcommand
	
	# we make sure that java had enough time to start as it is starting in the background    
	sleep 1

	PID=$(myjavapid) || true
	echo "${Description} is now running (pid $PID)"
}

stop() {
	start-stop-daemon --stop --quiet --pidfile $pidfile
	if [ -e $pidfile ] ; then
		rm -f $pidfile
	fi
	echo "${Description} is now stopped"
}

myjavapid() {
	if [ -e "$pidfile" ]; then
		if pidof java | tr ' ' '\n' | grep -w $(cat $pidfile); then
			return 0
		fi
	fi
	return 1
}

case "$1" in
  start)
	start
	;;
  stop)
	stop
	;;
  restart|reload|force-reload)
  	stop
	sleep 2
  	start
	;;
  status)
	PID=$(myjavapid) || true
	if [ -n "$PID" ]; then
		echo "${Description} is running (pid $PID)"
	else
		echo "${Description} is not running"
	fi
	;;
  *)
	echo $"Usage: $0 {start|stop|restart|status}"
	exit 1
esac

exit 0


